.. title: Welcome to Nikola
.. slug: welcome-to-nikola
.. date: 2012-03-30 23:00:00 UTC-03:00
.. tags: nikola, python, demo, blog
.. author: Roberto Alsina
.. link: https://getnikola.com/
.. description:
.. category: nikola

.. figure:: http://farm1.staticflickr.com/138/352972944_4f9d568680.jpg
   :target: http://farm1.staticflickr.com/138/352972944_4f9d568680_z.jpg?zz=1
   :class: thumbnail
   :alt: Nikola Tesla Corner by nicwest, on Flickr

If you can see this in a web browser, it means you did something wrong, because
you should be reading a nice post with links, and this should be used in
the test suite only.

Next steps:

* Read the manual
* Visit the Nikola website to learn more
* See a demo photo gallery
* See a demo listing
* See a demo slideshow
* See a demo of the Bootstrap theme

Send feedback to info@getnikola.com!
